﻿using System;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace CmdjyHisFront.Dal.Tables
{
    /// <summary>
    /// HIS发送的药品信息
    /// </summary>
    [Table("DjyDrugInfo")]
    public class DjyDrugInfo
    {
        /// <summary>
        /// 主键，药品流水号
        /// </summary>
        [Key]
        public int Id { get; set; }
        /// <summary>
        /// 记录创建时间
        /// </summary>
        public DateTime CreateDatetime { get; set; }
        /// <summary>
        /// 处方流水号
        /// </summary>
        public int PrescriptionId { get; set; }
        /// <summary>
        /// 发送请求的原始IP地址
        /// </summary>
        public string RawAddress { get; set; }
        /// <summary>
        /// "药品医保代码":"YP0306401000650",
        /// </summary>
        public string DrugNo { get; set; }
        /// <summary>
        /// 药品单价 0.085
        /// </summary>
        public string Price { get; set; }
        /// <summary>
        /// 单贴数量
        /// </summary>
        public string Count { get; set; }
        /// <summary>
        /// 单位 克
        /// </summary>
        public string Unit { get; set; }
        /// <summary>
        /// 单项总价
        /// </summary>
        public string Sum { get; set; }
        /// <summary>
        /// 规格  15.00000000
        /// </summary>
        public string DrugType { get; set; }
        /// <summary>
        /// 药品编码
        /// </summary>
        public string DrugLocalNo { get; set; }
        /// <summary>
        /// 药品名称
        /// </summary>
        public string DrugName { get; set; }
        /// <summary>
        /// 特殊要求
        /// </summary>
        public string Remark { get; set; }
        /// <summary>
        /// 上传状态
        /// </summary>
        public EnumDrugPostStatus PostStatus { get; set; }

    }

    /// <summary>
    /// 处方信息上传状态
    /// </summary>
    [Flags]
    public enum EnumDrugPostStatus
    {
        /// <summary>
        /// 新药品，未上传
        /// </summary>
        NewOrder = 0,
        /// <summary>
        /// 成功上传
        /// </summary>
        Sucess = 1,
        /// <summary>
        /// 上传异常
        /// </summary>
        Exception = 2,
        /// <summary>
        /// 取消上传
        /// </summary>
        Cancel = 4
    }

}